<?php

namespace Drupal\entity_update_tests;

/**
 * EntityUpdateTest Helper functions.
 */
class EntityUpdateTestHelper {

  /**
   * Get Configuration Name.
   */
  public static function getConfigName() {
    return 'entity_update_tests.settings';
  }

  /**
   * Get Configuration Object.
   *
   * @param bool $editable
   *   Readonly or Editable.
   *
   * @return \Drupal\Core\Config\Config|\Drupal\Core\Config\ImmutableConfig
   *   The configuration object.
   */
  public static function getConfig($editable = FALSE) {
    if ($editable) {
      $config = \Drupal::configFactory()->getEditable(static::getConfigName());
    }
    else {
      $config = \Drupal::config(static::getConfigName());
    }
    return $config;
  }

  /**
   * Enable a configurable field.
   */
  public static function fieldEnable($name, $enable = TRUE) {
    $config = self::getConfig(TRUE);
    $config->set("fields." . $name, $enable);
    $config->save();
  }

  /**
   * Disable a configurable field.
   */
  public static function fieldDisable($name) {
    return self::fieldEnable($name, FALSE);
  }

  /**
   * Get a configurable field status.
   */
  public static function fieldStatus($name) {
    return self::getConfig()->get("fields." . $name);
  }

}
