<?php

namespace Drupal\entity_update_tests\Tests;

use Drupal\simpletest\WebTestBase;
use Drupal\entity_update\EntityUpdate;
use Drupal\entity_update_tests\EntityUpdateTestHelper;
use Drupal\entity_update_tests\Entity\EntityUpdateTestsContentEntity;

/**
 * Test Entity Update functions.
 *
 * @group Entity Update
 */
class EntityUpdateFunctionsTest extends WebTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = ['entity_update', 'entity_update_tests'];

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();

    // Initialy, Disable the field 'name' => No need to update.
    EntityUpdateTestHelper::fieldDisable('name');
  }

  /**
   * Entity update function : basic.
   */
  public function testEntityUpdateBasic() {

    // Disable the field 'name' => No need to update.
    EntityUpdateTestHelper::fieldDisable('name');
    $list = EntityUpdate::getEntityTypesToUpdate();
    $this->assert(count($list) === 0, 'Every entities are up to date.');

    // Enable the field.
    EntityUpdateTestHelper::fieldEnable('name');

    // Get updates list.
    $list = EntityUpdate::getEntityTypesToUpdate();

    // Has one field to update.
    $this->assert(count($list) === 1, 'Has only one entity type to update.');

    // Analyse Entity to update.
    $first_item = reset($list);
    $first_key = key($list);
    $this->assert($first_key === 'entity_update_tests_cnt', 'The first key is "entity_update_tests_cnt".');
    $this->assert(count($first_item) === 1, 'The "entity_update_tests_cnt" has one change.');
    // Get first change.
    $entity_change_summ = reset($first_item);
    $temp = strip_tags($entity_change_summ);
    $this->assertEqual($temp, 'The Name field needs to be installed.', 'Summary text is correct.');

    // Make Update.
    $res = EntityUpdate::basicUpdate();
    $this->assert($res, 'Entity schema has been updated.');

    // Get updates list and check.
    $list = EntityUpdate::getEntityTypesToUpdate();
    $this->assert(count($list) === 0, 'Every entities are up to date.');

    // Disable the field 'name'.
    EntityUpdateTestHelper::fieldDisable('name');

    // Has one field to update.
    $list = EntityUpdate::getEntityTypesToUpdate();
    $this->assert(count($list) === 1, 'Has one entity type to update.');
  }

  /**
   * Entity update function : all.
   */
  public function testEntityUpdateAll() {

    // Create an entity.
    EntityUpdateTestsContentEntity::create(['id' => 1])->save();
    $ids = \Drupal::entityQuery('entity_update_tests_cnt')->execute();
    $this->assert(count($ids) === 1, 'Has one entity.');
    // Enable the field.
    EntityUpdateTestHelper::fieldEnable('name');
    // Check update.
    $this->assert(count(EntityUpdate::getEntityTypesToUpdate()) === 1, 'Has one entity type to update.');
    // Make Update.
    $res = EntityUpdate::safeUpdateMain();
    $this->assert($res, 'Entity schema has been updated.');
    // Check update.
    $this->assert(count(EntityUpdate::getEntityTypesToUpdate()) === 0, 'Entity type updated.');

    // Disable the field 'name'.
    EntityUpdateTestHelper::fieldDisable('name');
    // Check update.
    $this->assert(count(EntityUpdate::getEntityTypesToUpdate()) === 1, 'Has one entity type to update.');
    // Make Update.
    $res = EntityUpdate::safeUpdateMain();
    $this->assert($res, 'Entity schema has been updated.');
    // Check update.
    $this->assert(count(EntityUpdate::getEntityTypesToUpdate()) === 0, 'Entity type updated.');
  }

  /**
   * Entity update function : clean.
   */
  public function testEntityUpdateClean() {
    // Create an entity.
    EntityUpdateTestsContentEntity::create(['id' => 1])->save();
    $ids = \Drupal::entityQuery('entity_update_tests_cnt')->execute();
    $this->assert(count($ids) === 1, 'Has one entity.');
    // Enable the field.
    EntityUpdateTestHelper::fieldEnable('name');
    // Make Update.
    $res = EntityUpdate::safeUpdateMain();
    $this->assert($res, 'Entity schema has been updated.');
    // Cleanup function.
    $res = EntityUpdate::cleanupEntityBackup();
    $this->assert($res, 'Table cleanup END.');
  }

}
