<?php

namespace Drupal\entity_update;

/**
 * EntityCheck Main Class.
 */
class EntityCheck {

  /**
   * Get entity types list.
   *
   * @param string $type
   *   The entity type id.
   * @param bool $print
   *   Print to the drush terminal.
   *
   * @return array
   *   The table (Renderer array).
   */
  public static function getEntityTypesList($type = NULL, $print = TRUE) {
    $itmes_list = \Drupal::entityTypeManager()->getDefinitions();

    $table = [
      '#theme' => 'table',
      '#cache' => ['max-age' => 0],
      '#caption' => 'Entity types list',
      '#header' => ['Type ID', 'Type', 'Name'],
      '#rows' => [],
    ];

    foreach ($itmes_list as $itme_name => $item_object) {
      // Excluse if filtred by type.
      if ($type && strstr($itme_name, $type) === FALSE) {
        continue;
      }
      $table['#rows'][] = [
        $itme_name,
        $item_object->getGroup(),
        $item_object->getLabel(),
      ];
    }

    // Print table.
    if ($print) {
      EntityUpdatePrint::drushPrintTable($table);
    }
    return $table;
  }

  /**
   * Get entity list.
   *
   * @param string $type
   *   The entity type id.
   * @param int $start
   *   Start from.
   * @param int $length
   *   The max length.
   * @param bool $print
   *   Print to the drush terminal.
   *
   * @return array
   *   The table (Renderer array).
   */
  public static function getEntityList($type, $start = 0, $length = 10, $print = TRUE) {

    // Cast to integer.
    $start = (int) $start;
    $length = (int) $length;
    $entities = [];

    try {
      // Get entities list.
      $query = \Drupal::entityQuery($type);
      if ($length) {
        $query->range($start, $length);
      }
      $ids = $query->execute();
      $entities = \Drupal::entityTypeManager()->getStorage($type)->loadMultiple($ids);
    }
    catch (\Exception $ex) {
      EntityUpdatePrint::drushLog($ex->getMessage(), 'error');
      return NULL;
    }

    // Create table.
    $table = [
      '#theme' => 'table',
      '#caption' => 'List of the entities : ' . $type,
      '#header' => ['ID', 'Label'],
      '#rows' => [],
    ];
    foreach ($entities as $id => $entiy) {
      $table['#rows'][] = [$id, $entiy->label()];
    }

    // Print table.
    if ($print) {
      EntityUpdatePrint::drushPrintTable($table);
    }
    return $table;
  }

}
